Index: views/views_delegate.h |
=================================================================== |
--- views/views_delegate.h (revision 98696) |
+++ views/views_delegate.h (working copy) |
@@ -12,7 +12,6 @@ |
#endif |
#include "ui/base/accessibility/accessibility_types.h" |
-#include "ui/base/ui_base_types.h" |
#include "views/views_export.h" |
namespace gfx { |
@@ -47,20 +46,23 @@ |
// TODO(beng): perhaps this should be a Widget. |
virtual View* GetDefaultParentView() = 0; |
// Saves the position, size and "show" state for the window with the |
// specified name. |
virtual void SaveWindowPlacement(const Widget* widget, |
const std::wstring& window_name, |
const gfx::Rect& bounds, |
- ui::WindowShowState show_state) = 0; |
+ bool maximized) = 0; |
- // Retrieves the saved position and size and "show" state for the window with |
- // the specified name. |
- virtual bool GetSavedWindowPlacement( |
- const std::wstring& window_name, |
- gfx::Rect* bounds, |
- ui::WindowShowState* show_state) const = 0; |
+ // Retrieves the saved position and size for the window with the specified |
+ // name. |
+ virtual bool GetSavedWindowBounds(const std::wstring& window_name, |
+ gfx::Rect* bounds) const = 0; |
+ // Retrieves the saved maximized state for the window with the specified |
+ // name. |
+ virtual bool GetSavedMaximizedState(const std::wstring& window_name, |
+ bool* maximized) const = 0; |
+ |
virtual void NotifyAccessibilityEvent( |
views::View* view, ui::AccessibilityTypes::Event event_type) = 0; |
@@ -47,20 +46,23 @@ |
// TODO(beng): perhaps this should be a Widget. |
virtual View* GetDefaultParentView() = 0; |
- // Saves the position, size and "show" state for the window with the |
+ // Saves the position, size and maximized state for the window with the |
// specified name. |
virtual void SaveWindowPlacement(const Widget* widget, |